@@ -4,11 +4,11 @@ from .polytomous_utils import *
 from .synthetic import *
 from .latent_ability_distribution import *
 from .ability_methods import *
-from .multidimensional_ability_methods import *
 from .mml_methods import *
 from .mml_full_methods import *
 from .mml_eap_methods import *
-from .multidimensional_mml_methods import *
 from .conditional_methods import *
 from .jml_methods import *
-from .bootstrap_errors import *
\ No newline at end of file
+from .bootstrap_errors import *
+
+from .multidimensional import *
\ No newline at end of file
